/**
 * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
CKEDITOR.plugins.setLang( 'widget', 'ug', {
	'move': 'يۆتكەشتە چېكىپ سۆرەڭ',
	'label': '1% بېزەك'
} );
